<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR" sourcelanguage="en">
<context>
    <name>APTSourceEdit</name>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="14"/>
        <source>APT Repository Edit</source>
        <translation>APT Depo Düzenle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="38"/>
        <source>APT Repository</source>
        <translation>APT Depo</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="48"/>
        <source>Components</source>
        <translation>Komponentler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="55"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="71"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="87"/>
        <source>Fields cannot be left blank.</source>
        <translation>Alanları boş bırakmayın. </translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="94"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="110"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
        <source>Suites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="152"/>
        <source>Source</source>
        <translation>Kaynak</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="177"/>
        <source>Binary</source>
        <translation>İkili</translation>
    </message>
</context>
<context>
    <name>APTSourceManagerPage</name>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="188"/>
        <source>Search...</source>
        <translation>Arama...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="226"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="14"/>
        <source>APT Repository Manager</source>
        <translation>APT Depo Yönetimi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="125"/>
        <source>Not Found APT Repositories</source>
        <translation>APT Deposu bulunamadı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="269"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="308"/>
        <source>Enable Source</source>
        <translation>Kaynağı Etkinleştir</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
        <source>Add Repository</source>
        <translation>Depo Ekle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="371"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="419"/>
        <source>Select to delete or edit.</source>
        <translation>Silmek veya düzenlemek için seçim yapın.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="24"/>
        <source>example %1</source>
        <translation>örnek %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
        <source>APT Repositories (%1)</source>
        <translation>APT Depolar (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
        <source>Adding...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>APTSourceRepositoryItem</name>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_repository_item.cpp" line="35"/>
        <source>%1 (Source Code)</source>
        <translation>%1 (Kaynak Kod)</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="../stacer/app.ui" line="101"/>
        <source>Dashboard</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="135"/>
        <source>Startup Apps</source>
        <translation>Başlangıç Uygulamaları</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="163"/>
        <source>System Cleaner</source>
        <translation>Sistem Temizleyici</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="194"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="278"/>
        <source>Uninstaller</source>
        <translation>Kaldırıcı</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="306"/>
        <source>Resources</source>
        <translation>Kaynaklar</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="334"/>
        <source>Helpers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="362"/>
        <source>APT Repository Manager</source>
        <translation>APT Depo Yönetimi</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="250"/>
        <source>Processes</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="222"/>
        <source>Services</source>
        <translation>Servisler</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="390"/>
        <source>Gnome Settings</source>
        <translation>Gnome Ayarları</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="418"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="459"/>
        <source>Feedback</source>
        <translation>Geri Bildirim</translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="108"/>
        <location filename="../stacer/app.cpp" line="115"/>
        <location filename="../stacer/app.cpp" line="173"/>
        <source>Quit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="110"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="113"/>
        <source>Don&apos;t ask again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="116"/>
        <source>Will the program continue to work in the system tray?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceSettings</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="44"/>
        <source>Screen Applications</source>
        <translation>Ekran Uygulamaları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="74"/>
        <source>Screen Reader</source>
        <translation>Ekran Okuyucu</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="100"/>
        <source>Screen Keyboard</source>
        <translation>Ekran Klavyesi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="136"/>
        <source>Background Image Mode</source>
        <translation>Arkaplan Resim Biçim</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="166"/>
        <source>Desktop Mode</source>
        <translation>Masaüstü Biçimi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="204"/>
        <source>Login Mode</source>
        <translation>Giriş Ekranı Biçimi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="252"/>
        <source>Icons</source>
        <translation>İkonlar</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="282"/>
        <source>Home Icon</source>
        <translation>Ev İkon</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="308"/>
        <source>Trash Icon</source>
        <translation>Çöp Kutusu İkon</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="321"/>
        <source>Mounted Volumes Icon</source>
        <translation>Bağlanan Cihazlar İkon</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="347"/>
        <source>Show Desktop Icons</source>
        <translation>Masaüstü İkonları Göster</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="373"/>
        <source>Network Icon</source>
        <translation>Ağ İkon</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Wallpaper</source>
        <translation>Duvar Kağıdı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Centered</source>
        <translation>Merkezi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Scaled</source>
        <translation>Sığdırılmış</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Stretched</source>
        <translation>Gergin</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Zoom</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Spanned</source>
        <translation>Yayılmış</translation>
    </message>
</context>
<context>
    <name>DashboardPage</name>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="20"/>
        <source>Dashboard</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="156"/>
        <source>SYSTEM INFO</source>
        <translation>SİSTEM BİLGİLERİ</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="230"/>
        <source>A new update is now available.</source>
        <translation>Şu anda mevcut güncelleme var.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="246"/>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="19"/>
        <source>MEMORY</source>
        <translation>BELLEK</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="20"/>
        <source>DISK</source>
        <translation>DİSK</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="21"/>
        <source>DOWNLOAD</source>
        <translation>İNDİRME</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="22"/>
        <source>UPLOAD</source>
        <translation>YÜKLEME</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="111"/>
        <source>Hostname: %1</source>
        <translation>Bilgisayar Adı: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="112"/>
        <source>Platform: %1</source>
        <translation>Platform: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="113"/>
        <source>Distribution: %1</source>
        <translation>Dağıtım: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="114"/>
        <source>Kernel Release: %1</source>
        <translation>Çekirdek Sürümü: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="115"/>
        <source>CPU Model: %1</source>
        <translation>CPU Modeli: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
        <source>CPU Core: %1</source>
        <translation>CPU Çekirdek: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
        <source>CPU Speed: %1</source>
        <translation>CPU Hızı: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
        <source>High CPU Usage</source>
        <translation>Yüksek CPU Kullanımı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="136"/>
        <source>The amount of CPU used is over %1%.</source>
        <translation>Kullanılan CPU miktarı %1% den fazla.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="164"/>
        <source>High Memory Usage</source>
        <translation>Yüksek Bellek Kullanımı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="165"/>
        <source>The amount of memory used is over %1%.</source>
        <translation>Kullanılan bellek miktarı %1% den fazla.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="208"/>
        <source>High Disk Usage</source>
        <translation>Yüksek Disk Kullanımı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="209"/>
        <source>The amount of disk used is over %1%.</source>
        <translation>Kullanılan disk miktarı %1% den fazla.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="247"/>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="251"/>
        <source>Total: %1</source>
        <translation>Toplam: %1</translation>
    </message>
</context>
<context>
    <name>Feedback</name>
    <message>
        <location filename="../stacer/feedback.ui" line="14"/>
        <source>Feedback</source>
        <translation>Geri Bildirim</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="61"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="68"/>
        <source>Email Address</source>
        <translation>Mail Adresi</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="97"/>
        <source>Send</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="120"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="54"/>
        <source>Message</source>
        <translation>Mesaj</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="78"/>
        <source>Send feedback</source>
        <translation>Geribildirim Gönder</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="46"/>
        <source>Email address is not valid !</source>
        <translation>Mail adresiniz geçerli değil !</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="51"/>
        <source>Your message must be at least 5 characters !</source>
        <translation>Mesajınız en az 5 karakter olmalı !</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="59"/>
        <source>Sending...</source>
        <translation>Gönderiliyor...</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="78"/>
        <source>&lt;font color=&apos;#2ecc71&apos;&gt;Your feedback has been successfully sent. Thanks!&lt;/font&gt;</source>
        <translation>&lt;font color=&apos;#2ecc71&apos;&gt;Geribildiriminiz başarıyla gönderildi.&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="80"/>
        <location filename="../stacer/feedback.cpp" line="85"/>
        <source>Something went wrong, try again !</source>
        <translation>Bir şeyler ters gitti, tekrar deneyin !</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="88"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="93"/>
        <source>Fields cannot be left blank !</source>
        <translation>Alanlar boş bırakılamaz !</translation>
    </message>
</context>
<context>
    <name>GnomeSettingsPage</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="14"/>
        <source>Gnome Settings</source>
        <translation>Gnome Ayarları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="49"/>
        <source>Unity Settings</source>
        <translation>Unity Ayarları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="81"/>
        <source>Window Manager</source>
        <translation>Pencere Yönetimi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="110"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
</context>
<context>
    <name>HelpersPage</name>
    <message>
        <location filename="../stacer/Pages/Helpers/helpers_page.ui" line="14"/>
        <source>Helpers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/helpers_page.ui" line="62"/>
        <source>Host Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HostManage</name>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
        <source>Save Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="110"/>
        <source>New Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="146"/>
        <source>IP Address *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="153"/>
        <source>Fully Qualified Name *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="160"/>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
        <source>Aliases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="176"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="26"/>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="100"/>
        <source>Hosts (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
        <source>IP Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
        <source>Full Qualified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="137"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="141"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="149"/>
        <source>The IP and Fully Qualified fields are required.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessesPage</name>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="14"/>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="55"/>
        <source>Processes</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="71"/>
        <source>All Processes</source>
        <translation>Bütün İşlemler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="96"/>
        <source>Search...</source>
        <translation>Arama...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="217"/>
        <source>End Process</source>
        <translation>İşlemi Sonlandır</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
        <source>Resident Memory</source>
        <translation>Yerleşmiş Bellek</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
        <source>%Memory</source>
        <translation>%Bellek</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
        <source>Virtual Memory</source>
        <translation>Sanal Bellek</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>Start Time</source>
        <translation>Başlangıç Zamanı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>State</source>
        <translation>Durum</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>Nice</source>
        <translation>Güzel</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>CPU Time</source>
        <translation>CPU Zamanı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>Session</source>
        <translation>Oturum</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>Process</source>
        <translation>İşlem</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="120"/>
        <source>Processes (%1)</source>
        <translation>İşlemler (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="215"/>
        <source>Refresh (%1)</source>
        <translation>Yenile (%1)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../stacer/Managers/setting_manager.cpp" line="61"/>
        <source>Dashboard</source>
        <translation>Genel</translation>
    </message>
</context>
<context>
    <name>ResourcesPage</name>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="14"/>
        <source>History of CPU</source>
        <translation>CPU Geçmişi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="15"/>
        <source>History of CPU Load Averages</source>
        <translation>CPU Yük Ortalamaları Geçmişi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="16"/>
        <source>History of Disk Read Write</source>
        <translation>Disk Okuma Yazma Geçmişi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="17"/>
        <source>History of Memory</source>
        <translation>Bellek Geçmişi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="18"/>
        <source>History of Network</source>
        <translation>Ağ Geçmişi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="106"/>
        <source>File System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="122"/>
        <source>File System Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="142"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="217"/>
        <source>Read: %1/s Total: %2</source>
        <translation>Okuma: %1/s Toplam: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="222"/>
        <source>Write: %1/s Total: %2</source>
        <translation>Yazma: %1/s Toplam: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="259"/>
        <source>%1 Minute Average: %2</source>
        <translation>%1 Dakika Ortalama: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="307"/>
        <source>Download: %1/s Total: %2</source>
        <translation>İndirme: %1/s Toplam: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="312"/>
        <source>Upload: %1/s  Total: %2</source>
        <translation>Gönderme %1/s  Toplam: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="356"/>
        <source>Swap: %1 (%2%) %3</source>
        <translation>Takas Alanı: %1 (%2%) %3</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="365"/>
        <source>Memory: %1 (%2%) %3</source>
        <translation>Dahili Hafıza: %1 (%2%) %3</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.ui" line="14"/>
        <source>Resources</source>
        <translation>Kaynaklar</translation>
    </message>
</context>
<context>
    <name>SearchPage</name>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="14"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="101"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="113"/>
        <source>Search...</source>
        <translation>Arama...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
        <source>Case Insensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="298"/>
        <source> minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="370"/>
        <source>Search as Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="377"/>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="406"/>
        <source>RegEx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="483"/>
        <source>Permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="490"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="27"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="514"/>
        <source>Readable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="530"/>
        <source>Writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="546"/>
        <source>Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="555"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="584"/>
        <source>Empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="591"/>
        <source>File or Folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="607"/>
        <source>Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="650"/>
        <source>Advanced Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="690"/>
        <source>BETA version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="25"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="26"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="28"/>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="29"/>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="30"/>
        <source>Creation Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="31"/>
        <source>Last Access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="32"/>
        <source>Last Modification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="33"/>
        <source>Last Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="88"/>
        <source>Open Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="92"/>
        <source>Move Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="96"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="129"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="132"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="140"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="149"/>
        <source>Choose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="135"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="136"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="137"/>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="138"/>
        <source>Symbolic Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="141"/>
        <source>Access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="142"/>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="143"/>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="145"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="150"/>
        <source>Smaller (&lt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="146"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="151"/>
        <source>Equal (=)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="147"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="152"/>
        <source>Greater (&gt;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="162"/>
        <source>Select Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="168"/>
        <source>Directory: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="177"/>
        <source>Advanced Search %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="195"/>
        <source>Select the search directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="293"/>
        <source>Somethings went wrong, try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="309"/>
        <source>%1 files found. Showing %2 of them.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServicesPage</name>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="14"/>
        <source>Services</source>
        <translation>Servisler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="137"/>
        <source>Startup at boot ?</source>
        <translation>Açılışta başlatma ?</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="190"/>
        <source>Running Now ?</source>
        <translation>Şimdi Çalışıyor ?</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="244"/>
        <source>Not Found System Service</source>
        <translation>Sistem Servisi Bulunamadı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="32"/>
        <source>Running Status</source>
        <translation>Çalışma Durumu</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="32"/>
        <source>Running</source>
        <translation>Çalışma</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="32"/>
        <source>Not Running</source>
        <translation>Çalışmıyor</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="33"/>
        <source>Startup Status</source>
        <translation>Başlangıç Durumu</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="33"/>
        <source>Enabled</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="33"/>
        <source>Disabled</source>
        <translation>Pasif</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="80"/>
        <source>System Services (%1)</source>
        <translation>Sistem Servisleri (%1)</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="20"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="97"/>
        <source>Memory Percent</source>
        <translation>Bellek Yüzde</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="129"/>
        <source>Disk Percent</source>
        <translation>Disk Yüzde</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="329"/>
        <source>App Quit Don&apos;t Ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="389"/>
        <source>Disks</source>
        <translation>Diskler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="158"/>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="171"/>
        <source>Autostart Stacer</source>
        <translation>Stacer&apos;ı otomatik başlat</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="229"/>
        <source>Alert messages (Show a warning after the specified percentage)</source>
        <translation>Uyarı mesajları (Belirtilen yüzdeyi geçince uyarı göster)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="402"/>
        <source>Start Page</source>
        <translation>Başlangıç Sayfası</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="213"/>
        <source>CPU Percent</source>
        <translation>CPU Yüzde</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="267"/>
        <source>Donate</source>
        <translation>Bağış Yap</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>Dashboard</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>Startup Apps</source>
        <translation>Başlangıç Uygulamaları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>System Cleaner</source>
        <translation>Sistem Temizleyici</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Services</source>
        <translation>Servisler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Processes</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Uninstaller</source>
        <translation>Kaldırıcı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Resources</source>
        <translation>Kaynaklar</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Helpers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartupApp</name>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app.ui" line="128"/>
        <source>Edit App</source>
        <translation>Uygulamayı Düzenle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app.ui" line="150"/>
        <source>Delete App</source>
        <translation>Uygulamayı Sil</translation>
    </message>
</context>
<context>
    <name>StartupAppEdit</name>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="20"/>
        <source>Startup App</source>
        <translation>Başlangıç Uygulaması</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="95"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="44"/>
        <source>Fields cannot be left blank.</source>
        <translation>Alanları boş bırakmayın. </translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="65"/>
        <source>App Comment</source>
        <translation>Uygulama Yorum</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="51"/>
        <source>App Name</source>
        <translation>Uygulama Adı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="58"/>
        <source>Generic Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="72"/>
        <source>App Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="79"/>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="108"/>
        <source>Application</source>
        <translation>Uygulama</translation>
    </message>
</context>
<context>
    <name>StartupAppsPage</name>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
        <source>Not Found Startup Apps</source>
        <translation>Başlangıç Uygulaması Bulunamadı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="14"/>
        <source>Startup Apps</source>
        <translation>Başlangıç Uygulamaları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="101"/>
        <source>Add Startup App</source>
        <translation>Başlangıç Uygulaması Ekle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
        <source>Startup Apps are disabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
        <source>Startup Applications (%1)</source>
        <translation>Başlangıç Uygulamaları (%1)</translation>
    </message>
</context>
<context>
    <name>SystemCleanerPage</name>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="14"/>
        <source>System Cleaner</source>
        <translation>Sistem Temizleyici</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="66"/>
        <source>Crash Reports</source>
        <translation>Kilitlenme Raporları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="180"/>
        <source>Application Logs</source>
        <translation>Uygulama Günlükleri</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="218"/>
        <source>Application Caches</source>
        <translation>Uygulama Önbellekleri</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="366"/>
        <source>Trash</source>
        <translation>Çöp</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="404"/>
        <source>Package Caches</source>
        <translation>Paket Önbellekleri</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="493"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="638"/>
        <source>Select all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
        <source> Back</source>
        <translation> Geri</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="759"/>
        <source>Sort by: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="773"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="782"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="33"/>
        <source>File Name</source>
        <translation>Dosya Adı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="180"/>
        <source>Total size: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="791"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="800"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="33"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="293"/>
        <source>%1 size files cleaned.</source>
        <translation>%1 boyutunda dosya temizlendi.</translation>
    </message>
</context>
<context>
    <name>UninstallerPage</name>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="14"/>
        <source>Uninstaller</source>
        <translation>Kaldırıcı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
        <source>System Packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="393"/>
        <source>Snap Packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="442"/>
        <source>Search...</source>
        <translation>Arama...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="108"/>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="231"/>
        <source>Not Found Installed Packages</source>
        <translation>Yüklü Uygulama Bulunamadı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
        <source>Uninstall Selected</source>
        <translation>Seçilenleri Kaldır</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="102"/>
        <source>Packages (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="107"/>
        <source>Snap Packages (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="208"/>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="215"/>
        <source>Uninstall Selected (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UnitySettings</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="65"/>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="108"/>
        <source>Show &quot;Recently Used&quot; applications</source>
        <translation>Göster &quot;Son Kullanılan&quot; uygulamalar</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="134"/>
        <source>Enable search of your files</source>
        <translation>Dosyalarınızı aramayı etkinleştirin</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="160"/>
        <source>Show &quot;More Suggestions&quot;</source>
        <translation>Göster &quot;Daha Fazla Öneri&quot;</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="186"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="196"/>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="683"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="229"/>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="660"/>
        <source>Transparency Level</source>
        <translation>Şeffaflık Seviyesi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="280"/>
        <source>Behaviour</source>
        <translation>Davranış</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="323"/>
        <source>Auto Hide</source>
        <translation>Otomatik Gizle</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="339"/>
        <source>Left Side</source>
        <translation>Sol Kısım</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="380"/>
        <source>Minimize applications with clicking</source>
        <translation>Tıklayarak uygulamaları küçültün</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="396"/>
        <source>Top-Left Corner</source>
        <translation>Sol Üst Köşe</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="412"/>
        <source>Reveal Sensitivity</source>
        <translation>Hassasiyeti Göster</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="438"/>
        <source>Reveal Location</source>
        <translation>Konumu Göster</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="464"/>
        <source>Launcher</source>
        <translation>Başlatıcı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="474"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="507"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="526"/>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="542"/>
        <source>Visibility</source>
        <translation>Görünürlük</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="558"/>
        <source>Primary Desktop</source>
        <translation>Birincil Masaüstü</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="612"/>
        <source>Icon size</source>
        <translation>Simge boyutu</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="628"/>
        <source>All Desktops</source>
        <translation>Tüm Masaüstü</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="644"/>
        <source>Position</source>
        <translation>Pozisyon</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="726"/>
        <source>Search online sources</source>
        <translation>Çevrimiçi arama kaynağı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="752"/>
        <source>Background Blur</source>
        <translation>Arka Plan Bulanıklığı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="778"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="801"/>
        <source>Indicators</source>
        <translation>Göstergeler</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="840"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="862"/>
        <source>Calendar</source>
        <translation>Takvim</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="875"/>
        <source>Date &amp; Time</source>
        <translation>Tarih &amp; Zaman</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="888"/>
        <source>24-Hour Time</source>
        <translation>24 Saat Dilimi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="910"/>
        <source>Weekday</source>
        <translation>İş Günü</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="923"/>
        <source>Include</source>
        <translation>Dahil Et</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="945"/>
        <source>Seconds</source>
        <translation>Saniye</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="958"/>
        <source>Volume</source>
        <translation>Ses</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="971"/>
        <source>Show my name</source>
        <translation>İsmimi göster</translation>
    </message>
</context>
<context>
    <name>WindowManagerSettings</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="90"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="100"/>
        <source>Titlebar Actions</source>
        <translation>Başlık Çubuğu İşlemleri</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="155"/>
        <source>Right click</source>
        <translation>Sağ tıklama</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="168"/>
        <source>Double click</source>
        <translation>Çift tıklama</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="181"/>
        <source>Middle click</source>
        <translation>Orta tıklama</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="257"/>
        <source>Additional</source>
        <translation>İlave</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="267"/>
        <source>Workspace Settings</source>
        <translation>Çalışma Alanı Ayarları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="310"/>
        <source>Vertical workspaces</source>
        <translation>Dikey çalışma alanları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="333"/>
        <source>Workspace switcher</source>
        <translation>Çalışma alanı değiştirici</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="356"/>
        <source>Horizontal workspaces</source>
        <translation>Yatay çalışma alanları</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="379"/>
        <source>Focus Behaviour</source>
        <translation>Odak Davranışı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="409"/>
        <source>Focus mode</source>
        <translation>Odak modu</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="460"/>
        <source>Raise on click</source>
        <translation>Tıklayınca büyüt</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="483"/>
        <source>Hardware Acceleration</source>
        <translation>Donanım Hızlandırma</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="538"/>
        <source>Text quality</source>
        <translation>Yazı kalitesi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="64"/>
        <source>Fast</source>
        <translation>Hızlı</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="64"/>
        <source>Good</source>
        <translation>İyi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="64"/>
        <source>Best</source>
        <translation>En İyi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="66"/>
        <source>Click</source>
        <translation>Tıklama</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="66"/>
        <source>Sloppy</source>
        <translation>Yarım</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="66"/>
        <source>Mouse</source>
        <translation>Fare</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Toggle Shade</source>
        <translation>Ekran Geçişi</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Maximize</source>
        <translation>Büyüt</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Maximize Horizontally</source>
        <translation>Yatay Büyüt</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Maximize Vertically</source>
        <translation>Dikey Büyüt</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Minimize</source>
        <translation>Küçült</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Lower</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
</context>
</TS>
